Getting help
============

If you are having trouble with AnyIO, make sure you've first checked the
:doc:`FAQ <faq>` to see if your question is answered there. If not, you have a couple
ways for getting support:

* Post a question on `Stack Overflow`_ and use the ``anyio`` tag
* Join the `python-trio/AnyIO`_ room on Gitter

.. _Stack Overflow: https://stackoverflow.com/
.. _python-trio/AnyIO: https://gitter.im/python-trio/AnyIO

Reporting bugs
==============

If you're fairly certain that you have discovered a bug, you can `file an issue`_ on
Github. If you feel unsure, come talk to us first! The issue tracker is **not** the
proper venue for asking support questions.

.. _file an issue: https://github.com/agronholm/anyio/issues
